#include "servo01.h"
#include <stdbool.h>
#include "io430.h"

int setServoAndRead(int percentage);

int main(void)
{
  initialize();
  
  // LED-Pins auf Ausgang; LEDs aus.
  P1DIR |= BIT0 | BIT6;
  P1OUT &= ~BIT0 & ~BIT6;
  
  int bestPosition = 0;
  int bestBrightness = 0;
  for(int position = 0; position <= 100; position++)
  {
    int brightness = setServoAndRead(position);
    if(brightness > bestBrightness)
    {
      bestBrightness = brightness;
      bestPosition = position;
    }
  }
  int position = bestPosition;
  setServoTo(position);

  while(true)
  {
    bestBrightness = 0;
    for(int testPosition = position - 10; testPosition <= position + 10; testPosition += 10)
    {
      if(testPosition < 0 || testPosition > 100)
      {
        continue;
      }
      int brightness = setServoAndRead(testPosition);
      if(brightness > bestBrightness)
      {
        bestBrightness = brightness;
        bestPosition = testPosition;
      }
    }
    position = bestPosition; 
  }
  
  return 0;
}

int setServoAndRead(int percentage)
{
  setServoTo(percentage);
  
  // Wir nicht wissen, wo der Servo am Anfang steht.
  // Deshalb sicherheitshalber, damit
  // die erste Wartezeit immer lang genug ist:
  static int oldPercentage = 200;
  
  // LED an: > rot, < grn, == keine
  if(percentage > oldPercentage)
  {
    P1OUT |= BIT0; 
  }
  else if(percentage < oldPercentage)
  {
    P1OUT |= BIT6; 
  }
  
  // Mit der Funktion abs wre dies einfacher!
  int difference = percentage - oldPercentage;
  if(difference < 0)
  {
    difference *= -1;
  }
  waitMilliseconds(200+2*difference);

  // LEDs aus
  P1OUT &= ~BIT0 & ~BIT6;
  
  oldPercentage = percentage;
  
  return readAnalog();
}